Skip to contents

A "data.frame" containing the occurrence data of Apollo butterfly (Parnassius apollo), downloaded from the Global Biodiversity Information Facility website (www.gbif.org), on December 10, 2025. Used for examples and testing within the envar package.

Usage

Apollo

Format

A data.frame object :

X

longitude in WGS84

Y

latitude in WGS84

GBIF