A spatial dataset (class "sf", "data.frame") containing the borders of the European Alps region, retrieved from the Alpine Convention website (https://www.alpconv.org/fr/page-daccueil/). Used for examples and testing within the envar package.
A spatial dataset (class "sf", "data.frame") containing the borders of the European Alps region, retrieved from the Alpine Convention website (https://www.alpconv.org/fr/page-daccueil/). Used for examples and testing within the envar package.