Download and process EarthEnv habitat heterogeneity layers
Source:R/heterogeneity.R
heterogeneity.RdThis function downloads, processes, and extracts variables from the EarthEnv habitat heterogeneity dataset (1-km resolution). Each variable corresponds to a global Cloud-Optimized GeoTIFF (COG) representing different metrics of habitat heterogeneity derived from remote sensing data.
Arguments
- x
The output from `par_set()` defining the area or locations for extraction, the reference system, and the buffer. Leave this empty and use `par_set()` to define parameters for download.
- vars
Character vector of one or more variables to download and process.
- ...
Additional arguments (currently unused).
Value
If `par_set()` contained a raster/polygon/points with buffer: a `SpatRaster` stack of processed variables. If `par_set()` contained spatial points or data.frame of points without buffer: a `data.frame` of x, y, and extracted values.
Details
Available variables (working synonyms in parentheses):
First-order statistics
"cv" ("coefficient of variation", "coeff of variation")
"evenness" ("even")
"range"
"shannon" ("shannon index", "shannon entropy")
"simpson" ("simpson index", "simpson diversity")
"std" ("standard deviation", "std dev")
Second-order statistics (texture metrics)
"Contrast" ("contrast")
"Correlation" ("correlation", "corr")
"Dissimilarity" ("dissimilarity")
"Entropy" ("entropy", "texture entropy")
"Homogeneity" ("homogeneity")
"Maximum" ("maximum", "max")
"Uniformity" ("uniformity", "uniform")
"Variance" ("variance", "var")
Citation:
Tuanmu M-N, Jetz W (2015). "A global, remote sensing-based characterization of terrestrial habitat heterogeneity for biodiversity and ecosystem modeling." Global Ecology and Biogeography, 24, 1329-1339.
https://doi.org/10.1111/geb.12365
Note: Please cite original sources of primary datasets where appropriate.