Download and process Hybrid Global Annual 1-km IGBP Land Cover Maps
Source:R/hybridlandcover.R
hybridlandcover.RdThis function downloads, processes, and extracts land cover variables from the Hybrid Global Annual 1-km IGBP Land Cover Maps dataset (Luo et al., 2024). The data covers the period from 2000 to 2020.
Arguments
- x
The output from `par_set()` defining the area or locations for extraction, the reference system, and the buffer. Leave this empty and use `par_set()` to define parameters for download.
- vars
Character vector of one or more variables to download and process.
- year
Integer. The year for which to download the land cover map (2000-2020). Defaults to 2000.
- ...
Additional arguments (currently unused).
Value
If `par_set()` contained a raster/polygon/points with buffer: a `SpatRaster` stack of processed variables. If `par_set()` contained spatial points or data.frame of points without buffer: a `data.frame` of x, y, and extracted values.
Details
Available variables (working synonyms in parentheses):
1 - "landcover" ("cover", "land", "lc", "igbp", "hybrid")
Citation:
Luo Y, Zhu Z, Zhao W, Li M, Chen J, Zhao P, Sun L, Zhang Y, Duanmu Z, Chen J (2024). "Hybrid Global Annual 1-km IGBP Land Cover Maps for the Period 2000–2020." Journal of Remote Sensing, 4, 0122.
https://doi.org/10.34133/remotesensing.0122
Note: You must specify the `year` argument (integer between 2000 and 2020).